import TruebarClient from "./../TruebarClient.js"
import {Microphone} from "./Microphone.js";

/* !!!
This file is just a demonstration of Microphone.js and TruebarClient.js library usage. As such it is NOT production ready

Please note that library expects that some external dependencies are satisfied:
wave-resampler -> is packaged together with this example. It can also be included from CDN if desired.
axios -> In this example it is included from CDN inside index.html file. It can also be included in the same manner as wave-resampler if desired.
!!! */

let truebarClient = undefined;
let microphone = undefined;

document.getElementById("startBtn").onclick = async () => {

    // Create Truebar client object
    // Please check that the right addresses and user/pass are inserted
    truebarClient = await TruebarClient.build(
        "demo-auth.true-bar.si",
        443,
        "demo-api.true-bar.si",
        443,
        true,
        3000,
        "username",
        "password"
    )

    // Read current configuration from server and print it to the console
    let configuration = await truebarClient.getConfiguration();
    console.log("Current configuration is: ", configuration)


    // !Optionally! - modify any property that is allowed to be modified - please see documentation for details
    configuration.transcriptionLanguage = "sl-SI"
    configuration.transcriptionDomain = "MED"
    configuration.transcriptionModelVersion = "20210714-0909"

    // !Optionally! - in case any modification was made to configuration object it needs to be sent to the server. Only listed properties will be patched.
    console.log("Updating configuration...")
    await truebarClient.patchConfiguration(configuration)

    // Open transcription session and pass callback for response message processing as argument. For this example just print response message to the console.
    let sessionInfo = await truebarClient.openSession((msg) => {
        console.log(msg)
    })

    // Print information about created session
    // This can be used to resume given session at some later time - please see documentation for details
    console.log("Session info: ", sessionInfo);

    // Create microphone object (from the provided Microphone.js library) that can be used to capture live audio stream from microphone
    microphone = new Microphone();

    // Register callback that is called each time there is 'chunkSize' bytes captured from audio source. Also pass required sample rate.
    // The library captures and converts audio data to the required format (S16LE). It also performs resampling if necessary
    await microphone.initMicrophone(16000, 4096, (data) => {

        // Pass captured data to TruebarClient object
        truebarClient.sendAudioChunk(data)
    })

    // Call unlockAudio to actually start audio capturing
    await microphone.unlockAudio()

    console.log("Session started")
}

document.getElementById("stopBtn").onclick = async () => {

    // Stop audio capturing
    if (microphone !== undefined) {
        await microphone.lockAudio();
    }

    // Request session closing and wait for all already sent audio data to finish processing
    if (truebarClient !== undefined) {
        let closeMsg = await truebarClient.closeSession();

        console.log("Session closed with message: " + closeMsg)
    }
}